@@ -1,8 +1,12 @@
 import os
+from typing import Optional
 
 import click
 from click_aliases import ClickAliasedGroup
 
+from dragoneye.cloud_scanner.gcp.gcp_credentials_factory import GcpCredentialsFactory
+from dragoneye.cloud_scanner.gcp.gcp_scan_settings import GcpCloudScanSettings
+from dragoneye.cloud_scanner.gcp.gcp_scanner import GcpScanner
 from dragoneye.version import __version__
 from dragoneye.cloud_scanner.aws.aws_scanner import AwsScanner
 from dragoneye.cloud_scanner.aws.aws_session_factory import AwsSessionFactory
@@ -14,7 +18,7 @@ from dragoneye.utils.value_validator import validate_uuid, validate_path
 
 
 @click.group(name='scan',
-             help='Execute data-fetching API commands on a cloud account at a large scale quickly. Currently supported: AWS, Azure',
+             help='Execute data-fetching API commands on a cloud account at a large scale quickly. Currently supported: AWS, Azure, GCP',
              cls=ClickAliasedGroup)
 @click.version_option(__version__)
 def scan_cli():
@@ -28,6 +32,51 @@ def safe_cli_entry_point():
         click.echo(ex)
 
 
+@scan_cli.command(name='gcp',
+                  short_help='Scan a Google cloud provider account',
+                  help='Scan a Google cloud provider account. '
+                       '\n\nSCAN_COMMANDS_PATH: The file path to the yaml file that contains all the scan commands to run')
+@click.argument('scan-commands-path',
+                type=click.STRING)
+@click.argument('project-id',
+                type=click.STRING)
+@click.option('--cloud-account-name', '-n',
+              help='The name of your cloud account, the default value is \'default\'',
+              type=click.STRING,
+              default='default')
+@click.option('--project-id',
+              help='The ID of the project to scan',
+              type=click.STRING,)
+@click.option('--clean',
+              help='Remove any existing data for the account before gathering',
+              is_flag=True,
+              default=True)
+@click.option('--output-path',
+              help='The path in which the scan results will be saved on. Defaults to current working directory.',
+              type=click.STRING,
+              default=os.getcwd())
+@click.option('--credentials-path',
+              help='The path to the `Google Application Credentials` json file. If left empty, will attempt to get the default credentials',
+              type=click.STRING,
+              default=None)
+def gcp(scan_commands_path: str, project_id: str, clean: bool, output_path: str, cloud_account_name: str, credentials_path: Optional[str]):
+    validate_path(scan_commands_path, f'Could not find file: {scan_commands_path}')
+
+    gcp_scan_settings = GcpCloudScanSettings(commands_path=scan_commands_path,
+                                             account_name=cloud_account_name,
+                                             output_path=output_path,
+                                             should_clean_before_scan=clean,
+                                             project_id=project_id)
+    if credentials_path:
+        validate_path(credentials_path, f'Could not find file: {credentials_path}')
+        credentials = GcpCredentialsFactory.from_service_account_file(credentials_path)
+    else:
+        credentials = GcpCredentialsFactory.get_default_credentials()
+
+    output_path = GcpScanner(credentials, gcp_scan_settings).scan()
+    click.echo(f'Results saved to {output_path}')
+
+
 @scan_cli.command(name='azure',
                   short_help='Scan an Azure cloud account',
                   help='Scan an Azure cloud account. '
@@ -51,8 +100,8 @@ def safe_cli_entry_point():
 @click.option('--client-secret', '-s',
               help='The client secret of an application created in Azure. If not specified, will use credentials from `az login`',
               type=click.STRING)
-@click.option("--clean",
-              help="Remove any existing data for the account before gathering",
+@click.option('--clean',
+              help='Remove any existing data for the account before gathering',
               is_flag=True,
               default=True)
 @click.option('--output-path',
@@ -63,7 +112,7 @@ def azure(cloud_account_name: str,
           subscription_id: str, client_id: str, client_secret: str, tenant_id: str,
           scan_commands_path, clean, output_path):
     validate_uuid(subscription_id, 'Invalid subscription id')
-    validate_path(scan_commands_path)
+    validate_path(scan_commands_path, f'Could not find file: {scan_commands_path}')
 
     azure_scan_settings = AzureCloudScanSettings(
         commands_path=scan_commands_path,
@@ -89,12 +138,12 @@ def azure(cloud_account_name: str,
 @click.option('--profile',
               help='aws profile',
               type=click.STRING)
-@click.option("--regions",
-              help="Filter and query AWS only for the given regions (comma separated)",
+@click.option('--regions',
+              help='Filter and query AWS only for the given regions (comma separated)',
               type=click.STRING,
               default='')
-@click.option("--clean",
-              help="Remove any existing data for the account before gathering",
+@click.option('--clean',
+              help='Remove any existing data for the account before gathering',
               is_flag=True,
               default=True)
 @click.option('--output-path',
@@ -119,7 +168,7 @@ def aws(cloud_account_name,
         output_path=output_path,
         default_region=default_region)
 
-    validate_path(scan_commands_path)
+    validate_path(scan_commands_path, f'Could not find file: {scan_commands_path}')
     session = AwsSessionFactory.get_session(profile, default_region)
     output_path = AwsScanner(session, aws_scan_settings).scan()
     click.echo(f'Results saved to {output_path}')
